@@ -3,7 +3,6 @@
 import os
 import sys
 import configparser
-import shutil
 from pathlib import Path
 from typing import Dict, Optional, Any, Callable
 
@@ -13,7 +12,7 @@ from .i18n import _
 RUNNING_AS_ROOT = os.geteuid() == 0
 
 
-VERSION = '1.6.7-dev'
+VERSION = '1.6.9-dev'
 
 _USER_CACHE_HOME = os.environ.get(
     "XDG_CACHE_HOME",
@@ -32,9 +31,11 @@ CONFIG_ROOT = os.environ.get(
     os.path.join(Path.home(), ".config/")
 )
 
-DATA_ROOT = os.environ.get(
-    "XDG_DATA_HOME",
-    os.path.join(Path.home(), ".local/share/pikaur")
+DATA_ROOT = os.path.join(
+    os.environ.get(
+        "XDG_DATA_HOME",
+        os.path.join(Path.home(), ".local/share/")
+    ), "pikaur"
 )
 _OLD_AUR_REPOS_CACHE_PATH = os.path.join(CACHE_ROOT, 'aur_repos')
 if RUNNING_AS_ROOT:
@@ -43,27 +44,6 @@ else:
     AUR_REPOS_CACHE_PATH = os.path.join(DATA_ROOT, 'aur_repos')
 
 
-def migrate_old_aur_repos_dir() -> None:
-    if not (
-            os.path.exists(_OLD_AUR_REPOS_CACHE_PATH) and not os.path.exists(AUR_REPOS_CACHE_PATH)
-    ):
-        return
-    if not os.path.exists(DATA_ROOT):
-        os.makedirs(DATA_ROOT)
-    shutil.move(_OLD_AUR_REPOS_CACHE_PATH, AUR_REPOS_CACHE_PATH)
-
-    # pylint:disable=import-outside-toplevel
-    from .pprint import print_warning, print_stderr
-    print_stderr()
-    print_warning(
-        _("AUR repos dir has been moved from '{old}' to '{new}'.".format(
-            old=_OLD_AUR_REPOS_CACHE_PATH,
-            new=AUR_REPOS_CACHE_PATH
-        ))
-    )
-    print_stderr()
-
-
 def get_config_path() -> str:
     config_flag = '--pikaur-config'
     if config_flag in sys.argv:
