@@ -567,11 +567,11 @@ class InstallPackagesCLI():
                     raise SysExit(125)
 
     def ask_about_package_conflicts(self) -> None:
-        if self.aur_packages_names:
+        if self.aur_packages_names or self.aur_deps_names:
             print_stderr(_('looking for conflicting AUR packages...'))
             self.found_conflicts.update(
                 find_aur_conflicts(
-                    self.aur_packages_names,
+                    self.aur_packages_names + self.aur_deps_names,
                     self.install_package_names
                 )
             )
@@ -834,6 +834,7 @@ class InstallPackagesCLI():
                 #     raise SysExit(125)
                 for _pkg_name in pkg_build.package_names:
                     failed_to_build_package_names.append(_pkg_name)
+                    packages_to_be_built.remove(_pkg_name)
                     self.discard_install_info(_pkg_name)
                     for remaining_aur_pkg_name in packages_to_be_built[:]:
                         if remaining_aur_pkg_name not in self.all_aur_packages_names:
